//Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.

#import <Foundation/Foundation.h>
#import <CoreData/CoreData.h>

/*!
 * This class stores the metadata information of a ResourceItem ie; files/folder.
 */

@interface PCResourceItem : NSObject
/*!
 * The name of the file.
 */
@property (nonatomic, readonly, copy) NSString *name;

/*!
 * The size of the file, in bytes.
 */
@property (nonatomic, readonly, strong) NSNumber *size;

/*!
 * Creation timestamp for the file's current version, in ISO-8601 format.
 */
@property (nonatomic, readonly, strong) NSDate *versionCreated;

/*!
 * A unique string representing the file. Will change if file content is updated. Required for certain APIs, such as /thumbnails.
 */
@property (nonatomic, readonly, copy) NSString *contentToken;

/*!
 * The file content's SHA-256 checksum value.
 */
@property (nonatomic, readonly, copy) NSString *checkSum;

/*!
 * The folder where the file is located.
 */
@property (nonatomic, readonly, copy) NSString *parentPath;

/*!
 * File version. This number increases when the file is updated.
 */
@property (nonatomic, readonly, strong) NSNumber *version;

/*!
 * The file's extension, as extracted from the filename.
 */
@property (nonatomic, readonly, copy) NSString *extension;

/*!
 * Unique identifier of the resource.
 */
@property (nonatomic, readonly, copy) NSString *uri;

/*!
 * Tags of the resource.
 */
@property (nonatomic, readonly, copy) NSString *tags;

/*!
 * If true, the file has been logically deleted.
 */
@property (nonatomic, readonly, strong) NSNumber *deleted;

/*!
 * The full path to file/folder.
 */
@property (nonatomic, readonly, copy) NSString *fullPath;

/*!
 * Call this methods to create a PCResourceItem using a managedObjectID. managedObjectID is mapped with coredata object and a PCResourceItem is created out of the values copied from the coredata object.
 */
- (id)initWithDBResourceID:(NSManagedObjectID *)managedObjectID;


@end
